@@ -65,6 +65,9 @@ pub enum InstructionType {
 	Nop,
 	CurrentMemory,
 	GrowMemory,
+
+	#[cfg(feature = "sign_ext")]
+	SignExt,
 }
 
 impl FromStr for InstructionType {
@@ -92,6 +95,10 @@ impl FromStr for InstructionType {
 			"nop" => Ok(InstructionType::Nop),
 			"current_mem" => Ok(InstructionType::CurrentMemory),
 			"grow_mem" => Ok(InstructionType::GrowMemory),
+
+			#[cfg(feature = "sign_ext")]
+			"sign_ext" => Ok(InstructionType::SignExt),
+
 			_ => Err(UnknownInstruction),
 		}
 	}
@@ -290,6 +297,9 @@ impl InstructionType {
 			I64ReinterpretF64 => InstructionType::Reinterpretation,
 			F32ReinterpretI32 => InstructionType::Reinterpretation,
 			F64ReinterpretI64 => InstructionType::Reinterpretation,
+
+			#[cfg(feature = "sign_ext")]
+			SignExt(_) => InstructionType::SignExt,
 		}
 	}
 }
